@@ -26,9 +26,7 @@ from astropy.coordinates.builtin_frames import _make_transform_graph_docs
 from astropy.coordinates.transformations import FunctionTransform, DynamicMatrixTransform
 from astropy.coordinates.matrix_utilities import rotation_matrix, matrix_product, matrix_transpose
 from astropy.coordinates import HCRS, get_body_barycentric, BaseCoordinateFrame, ConvertError
-from astropy.tests.helper import quantity_allclose
 
-from .representation import SphericalWrap180Representation
 from .frames import (HeliographicStonyhurst, HeliographicCarrington,
                      Heliocentric, Helioprojective)
 
@@ -64,11 +62,15 @@ def hgs_to_hgc(hgscoord, hgcframe):
     """
     Transform from Heliographic Stonyhurst to Heliograpic Carrington.
     """
-    c_lon = hgscoord.spherical.lon + _carrington_offset(hgscoord.obstime).to(
-        u.deg)
+    if hgcframe.obstime is None or np.any(hgcframe.obstime != hgscoord.obstime):
+        raise ValueError("Can not transform from Heliographic Stonyhurst to "
+                         "Heliographic Carrington, unless both frames have matching obstime.")
+
+    c_lon = hgscoord.spherical.lon + _carrington_offset(hgscoord.obstime).to(u.deg)
     representation = SphericalRepresentation(c_lon, hgscoord.lat,
                                              hgscoord.radius)
     hgcframe = hgcframe.__class__(obstime=hgscoord.obstime)
+
     return hgcframe.realize_frame(representation)
 
 
@@ -78,14 +80,15 @@ def hgc_to_hgs(hgccoord, hgsframe):
     """
     Convert from Heliograpic Carrington to Heliographic Stonyhurst.
     """
-    if hgccoord.obstime:
-        obstime = hgccoord.obstime
-    else:
-        obstime = hgsframe.obstime
+    if hgsframe.obstime is None or np.any(hgsframe.obstime != hgccoord.obstime):
+        raise ValueError("Can not transform from Heliographic Carrington to "
+                         "Heliographic Stonyhurst, unless both frames have matching obstime.")
+    obstime = hgsframe.obstime
     s_lon = hgccoord.spherical.lon - _carrington_offset(obstime).to(
         u.deg)
-    representation = SphericalWrap180Representation(s_lon, hgccoord.lat,
-                                                    hgccoord.radius)
+    representation = SphericalRepresentation(s_lon, hgccoord.lat,
+                                             hgccoord.radius)
+
     return hgsframe.realize_frame(representation)
 
 
@@ -95,9 +98,6 @@ def hcc_to_hpc(helioccoord, heliopframe):
     """
     Convert from Heliocentic Cartesian to Helioprojective Cartesian.
     """
-    # Propagate obstime explicitly.
-    if heliopframe.obstime is None:
-        heliopframe._obstime = helioccoord._obstime
 
     x = helioccoord.x.to(u.m)
     y = helioccoord.y.to(u.m)
@@ -110,8 +110,9 @@ def hcc_to_hpc(helioccoord, heliopframe):
     hpcx = np.rad2deg(np.arctan2(x, helioccoord.observer.radius - z))
     hpcy = np.rad2deg(np.arcsin(y / distance))
 
-    representation = SphericalWrap180Representation(hpcx, hpcy,
-                                                    distance.to(u.km))
+    representation = SphericalRepresentation(hpcx, hpcy,
+                                             distance.to(u.km))
+
     return heliopframe.realize_frame(representation)
 
 
@@ -170,7 +171,7 @@ def hcc_to_hgs(helioccoord, heliogframe):
     hgln = np.arctan2(x, z * cosb - y * sinb) + l0_rad
     hglt = np.arcsin((y * cosb + z * sinb) / hecr)
 
-    representation = SphericalWrap180Representation(
+    representation = SphericalRepresentation(
         np.rad2deg(hgln), np.rad2deg(hglt), hecr.to(u.km))
     return heliogframe.realize_frame(representation)
 
@@ -181,6 +182,9 @@ def hgs_to_hcc(heliogcoord, heliocframe):
     """
     Convert from Heliographic Stonyhurst to Heliocentric Cartesian.
     """
+    # Import moved here from top of file to lessen the impact of issue #2580
+    # TODO: Revert this.
+    from astropy.tests.helper import quantity_allclose
     hglon = heliogcoord.lon
     hglat = heliogcoord.lat
     r = heliogcoord.radius
@@ -188,9 +192,6 @@ def hgs_to_hcc(heliogcoord, heliocframe):
         r = np.ones_like(r)
         r *= RSUN_METERS
 
-    if heliocframe.obstime is None:
-        heliocframe._obstime = heliogcoord.obstime
-
     if not isinstance(heliocframe.observer, BaseCoordinateFrame):
         raise ConvertError("Cannot transform heliographic coordinates to "
                            "heliocentric coordinates for observer '{}' "
@@ -230,6 +231,8 @@ def hpc_to_hpc(heliopcoord, heliopframe):
     This converts from HPC to HPC, with different observer location parameters.
     It does this by transforming through HGS.
     """
+    # TODO: Revert this.
+    from astropy.tests.helper import quantity_allclose
     if (heliopcoord.observer == heliopframe.observer or
         (quantity_allclose(heliopcoord.observer.lat, heliopframe.observer.lat) and
          quantity_allclose(heliopcoord.observer.lon, heliopframe.observer.lon) and
@@ -326,4 +329,12 @@ def hgs_to_hcrs(hgscoord, hcrsframe):
     return matrix_transpose(hcrs_to_hgs(hcrsframe, hgscoord))
 
 
+@frame_transform_graph.transform(FunctionTransform, HeliographicStonyhurst, HeliographicStonyhurst)
+def hgs_to_hgs(from_coo, to_frame):
+    if np.all(from_coo.obstime == to_frame.obstime):
+        return to_frame.realize_frame(from_coo.data)
+    else:
+        return from_coo.transform_to(HCRS).transform_to(to_frame)
+
+
 __doc__ += _make_transform_graph_docs()
